@@ -49,7 +49,7 @@ L<Devscripts::Uscan::WatchFile> code to see required keys.
 =item B<downloader>: L<Devscripts::Uscan::Downloader> object
 
 =item B<watchSource>: hash containing whatch sources options (built by
-L<Devscripts::Uscan::WatchFile> using L<Descripts::Uscan::WatchSource::Parser>
+L<Devscripts::Uscan::WatchFile> using L<Devscripts::Uscan::WatchSource::Parser>
 and L<Devscripts::Uscan::WatchSource::Transform>
 
 =item B<pkg>: Debian package name
